Installation — autoBOTLib documentation

# Installation

To install the stable version of the code, you can try:

    pip install autoBOTLib

Or for the current master branch

    pip install git+https://github.com/SkBlaz/autobot

Or directly from the repo

    python setup.py install

Requirements can be installed via (from the repo folder):

    pip install -r requirements.txt

We also provide the conda virtual env specification file (yml), found in the root directory of autoBOT repo.

    conda env create -f conda_env.yml

To test whether the core library functionality works well, you can run the test suite from the ./tests folder (autoBOT) as:

    py.test